@@ -240,7 +240,7 @@ def loadTransWF(wfs):
 @task()
 def doStringSelect(form):
     qs = WordForm.objects.all()
-    qs = qs.filter(lemma__category__in = form['categories']).select_related('lemma','lemma__category').prefetch_related('orthographies','transcriptions','word')
+    qs = qs.filter(lemma__category__in = form['categories']).select_related('lemma','lemma__category').prefetch_related('orthographies__word','transcriptions')
     if form['exclude_punctuation']:
         qs = qs.exclude(orthographies__spelling__contains="'")
         qs = qs.exclude(orthographies__spelling__contains=".")
